##  Overview
The SAP suggestions in your landscape extension to the meta model analyzes your workspace data and adds SAP suggestions for applications and AI agents to predefined reports, helping you identify optimization opportunities. You can create fact sheets from these suggestions to complete your inventory.
